@@ -4,10 +4,12 @@ import datetime
 import hashlib
 try:
     # python 3
-    from io import StringIO
+    from io import StringIO, BytesIO
+    IS_PYTHON_2 = False
 except ImportError:
     # python 2
     from StringIO import StringIO
+    IS_PYTHON_2 = True
 import time
 
 from ofxparse import OfxParser, AccountType
@@ -109,7 +111,14 @@ class Account(object):
         :type days: integer
         :rtype: :py:class:`ofxparser.Ofx`
         """
-        return OfxParser.parse(self.download(days=days))
+        if IS_PYTHON_2:
+            return OfxParser.parse(
+                self.download(days=days)
+            )
+        else:
+            return OfxParser.parse(
+                BytesIO(self.download(days=days).read().encode())
+            )
 
     def statement(self, days=60):
         """Download the :py:class:`ofxparse.Statement` given the time range
