@@ -17,8 +17,10 @@ except ImportError:
 import uuid
 
 DEFAULT_APP_ID = 'QWIN'
-DEFAULT_APP_VERSION = '2200'
+DEFAULT_APP_VERSION = '2500'
 DEFAULT_OFX_VERSION = '102'
+DEFAULT_USER_AGENT = 'httpclient'
+DEFAULT_ACCEPT = '*/*, application/x-ofx'
 
 LINE_ENDING = "\r\n"
 
@@ -40,6 +42,12 @@ class Client:
     :type app_version: string
     :param ofx_version: OFX spec version
     :type ofx_version: string
+    :param user_agent: Value to send for User-Agent HTTP header. Leave as
+      None to send default. Set to False to not send User-Agent header.
+    :type user_agent: str, None or False
+    :param accept: Value to send for Accept HTTP header. Leave as
+      None to send default. Set to False to not send User-Agent header.
+    :type accept: str, None or False
     """
 
     def __init__(
@@ -48,15 +56,39 @@ class Client:
         id=ofx_uid(),
         app_id=DEFAULT_APP_ID,
         app_version=DEFAULT_APP_VERSION,
-        ofx_version=DEFAULT_OFX_VERSION
+        ofx_version=DEFAULT_OFX_VERSION,
+        user_agent=DEFAULT_USER_AGENT,
+        accept=DEFAULT_ACCEPT
     ):
         self.institution = institution
         self.id = id
         self.app_id = app_id
         self.app_version = app_version
         self.ofx_version = ofx_version
+        self.user_agent = user_agent
+        self.accept = accept
+        # used when serializing Institutions
+        self._init_args = {
+            'id': self.id,
+            'app_id': self.app_id,
+            'app_version': self.app_version,
+            'ofx_version': self.ofx_version,
+            'user_agent': self.user_agent,
+            'accept': self.accept
+        }
         self.cookie = 3
 
+    @property
+    def init_args(self):
+        """
+        Return a dict of the arguments used to initialize this client,
+        suitable for use when serializing an Institution.
+
+        :return: constructor arguments
+        :rtype: dict
+        """
+        return self._init_args
+
     def authenticated_query(
         self,
         with_message=None,
@@ -94,26 +126,66 @@ class Client:
         return self.authenticated_query(self._acctreq(date))
 
     def post(self, query):
+        """
+        Wrapper around ``_do_post()`` to handle accounts that require
+        sending back session cookies (``self.set_cookies`` True).
+        """
+        res, response = self._do_post(query)
+        cookies = res.getheader('Set-Cookie', None)
+        if len(response) == 0 and cookies is not None and res.status == 200:
+            logging.debug('Got 0-length 200 response with Set-Cookies header; '
+                          'retrying request with cookies')
+            _, response = self._do_post(query, [('Cookie', cookies)])
+        return response
+
+    def _do_post(self, query, extra_headers=[]):
+        """
+        Do a POST to the Institution.
+
+        :param query: Body content to POST (OFX Query)
+        :type query: str
+        :param extra_headers: Extra headers to send with the request, as a list
+          of (Name, Value) header 2-tuples.
+        :type extra_headers: list
+        :return: 2-tuple of (HTTPResponse, str response body)
+        :rtype: tuple
+        """
         i = self.institution
         logging.debug('posting data to %s' % i.url)
-        logging.debug('---- request ----')
-        logging.debug(query)
         garbage, path = splittype(i.url)
         host, selector = splithost(path)
-        h = HTTPSConnection(host)
-        h.request('POST', selector, query,
-                  {
-                      "Content-type": "application/x-ofx",
-                      "Accept": "*/*, application/x-ofx"
-                  })
+        h = HTTPSConnection(host, timeout=60)
+        # Discover requires a particular ordering of headers, so send the
+        # request step by step.
+        h.putrequest('POST', selector, skip_host=True,
+                     skip_accept_encoding=True)
+        headers = [
+            ('Content-Type', 'application/x-ofx'),
+            ('Host', host),
+            ('Content-Length', len(query)),
+            ('Connection', 'Keep-Alive')
+        ]
+        if self.accept:
+            headers.append(('Accept', self.accept))
+        if self.user_agent:
+            headers.append(('User-Agent', self.user_agent))
+        for ehname, ehval in extra_headers:
+            headers.append((ehname, ehval))
+        logging.debug('---- request headers ----')
+        for hname, hval in headers:
+            logging.debug('%s: %s', hname, hval)
+            h.putheader(hname, hval)
+        logging.debug('---- request body (query) ----')
+        logging.debug(query)
+        h.endheaders(query.encode())
         res = h.getresponse()
         response = res.read().decode('ascii', 'ignore')
         logging.debug('---- response ----')
         logging.debug(res.__dict__)
+        logging.debug('Headers: %s', res.getheaders())
         logging.debug(response)
         res.close()
-
-        return response
+        return res, response
 
     def next_cookie(self):
         self.cookie += 1
