@@ -3,10 +3,12 @@ from __future__ import unicode_literals
 import hashlib
 try:
     # python 3
-    from io import StringIO
+    from io import StringIO, BytesIO
+    IS_PYTHON_2 = False
 except ImportError:
     # python 2
     from StringIO import StringIO
+    IS_PYTHON_2 = True
 
 from bs4 import BeautifulSoup
 from ofxparse import OfxParser
@@ -140,7 +142,10 @@ class Institution(object):
         resp = client.post(query)
         resp_handle = StringIO(resp)
 
-        parsed = OfxParser.parse(resp_handle)
+        if IS_PYTHON_2:
+            parsed = OfxParser.parse(resp_handle)
+        else:
+            parsed = OfxParser.parse(BytesIO(resp_handle.read().encode()))
 
         return [Account.from_ofxparse(a, institution=self)
                 for a in parsed.accounts]
@@ -160,22 +165,14 @@ class Institution(object):
             'password':    'Customer password',
             'description': 'descr',
             'client_args': {
-                'id':          'random client id - see Client() for default',
-                'app_id':      'app name - see Client() for default',
-                'app_version': 'app version - see Client() for default',
-                'ofx_version': 'ofx version - see Client() for default',
+                'id':     'random client id - see Client() for default',
+                'app_id': 'app name - see Client() for default',
+                '...':    'see Client() for other options'
             }
           }
 
         :rtype: nested dictionary
         """
-        client = self.client()
-        client_args = {
-            'id': client.id,
-            'app_id': client.app_id,
-            'app_version': client.app_version,
-            'ofx_version': client.ofx_version,
-        }
         return {
             'id': self.id,
             'org': self.org,
@@ -184,7 +181,7 @@ class Institution(object):
             'username': self.username,
             'password': self.password,
             'description': self.description,
-            'client_args': client_args,
+            'client_args': self.client().init_args,
             'local_id': self.local_id()
         }
 
